@@ -1,16 +1,12 @@
-import calendar
 from datetime import datetime, timedelta
 from typing import List, Optional
 
 import pytz
-from django.apps import apps
-from django.conf import settings
-from django.db.models import Count, Q
+from django.db.models import Count, Q, Sum
 from django.utils import timezone
 from music.models import Artist, Track
 from scrobbles.models import Scrobble
 from videos.models import Video
-
 from vrobbler.apps.profiles.utils import now_user_timezone
 
 NOW = timezone.now()
@@ -59,7 +55,9 @@ def scrobble_counts(user=None):
     return data
 
 
-def week_of_scrobbles(user=None, media: str = 'tracks') -> dict[str, int]:
+def week_of_scrobbles(
+    user=None, start=None, media: str = 'tracks'
+) -> dict[str, int]:
 
     now = timezone.now()
     user_filter = Q()
@@ -67,9 +65,8 @@ def week_of_scrobbles(user=None, media: str = 'tracks') -> dict[str, int]:
         now = now_user_timezone(user.profile)
         user_filter = Q(user=user)
 
-    start_of_today = datetime.combine(
-        now.date(), datetime.min.time(), now.tzinfo
-    )
+    if not start:
+        start = datetime.combine(now.date(), datetime.min.time(), now.tzinfo)
 
     scrobble_day_dict = {}
     base_qs = Scrobble.objects.filter(user_filter, played_to_completion=True)
@@ -81,13 +78,13 @@ def week_of_scrobbles(user=None, media: str = 'tracks') -> dict[str, int]:
         media_filter = Q(video__video_type=Video.VideoType.TV_EPISODE)
 
     for day in range(6, -1, -1):
-        start = start_of_today - timedelta(days=day)
-        end = datetime.combine(start, datetime.max.time(), now.tzinfo)
-        day_of_week = start.strftime('%A')
+        start_day = start - timedelta(days=day)
+        end = datetime.combine(start_day, datetime.max.time(), now.tzinfo)
+        day_of_week = start_day.strftime('%A')
 
         scrobble_day_dict[day_of_week] = base_qs.filter(
             media_filter,
-            timestamp__gte=start,
+            timestamp__gte=start_day,
             timestamp__lte=end,
             played_to_completion=True,
         ).count()
@@ -95,61 +92,8 @@ def week_of_scrobbles(user=None, media: str = 'tracks') -> dict[str, int]:
     return scrobble_day_dict
 
 
-def aggregator(
-    year: Optional[int] = None,
-    month: Optional[int] = None,
-    day: Optional[int] = None,
-    user=None,
-    model_str="Track",
-) -> dict[str, int]:
-    now = timezone.now()
-    tz = settings.TIME_ZONE
-    if user and user.is_authenticated:
-        now = now_user_timezone(user.profile)
-        tz = pytz.timezone(user.profile.timezone)
-
-    data_model = apps.get_model(app_label='music', model_name='Track')
-    if model_str == "Video":
-        data_model = apps.get_model(app_label='videos', model_name='Video')
-    if model_str == "SportEvent":
-        data_model = apps.get_model(
-            app_label='sports', model_name='SportEvent'
-        )
-
-    base_qs = data_model.objects.filter(
-        scrobble__user=user,
-        scrobble__played_to_completion=True,
-    )
-
-    if not year:
-        return base_qs.annotate(scrobble_count=Count("scrobble"))
-
-    start = datetime(year, 1, 1, tzinfo=tz)
-    end = datetime(year, 12, 31, tzinfo=tz)
-    if month:
-        end_day = calendar.monthrange(year, month)[1]
-        start = datetime(year, month, 1, tzinfo=tz)
-        end = datetime(year, month, end_day, tzinfo=tz)
-    if day:
-        start = datetime(year, month, day, 0, 0, tzinfo=tz)
-        end = datetime(year, month, day, 23, 59, tzinfo=tz)
-
-    date_filter = Q(
-        scrobble__timestamp__gte=start, scrobble__timestamp__lte=end
-    )
-
-    return base_qs.annotate(
-        num_scrobbles=Count("scrobble", filter=Q(date_filter))
-    ).filter(date_filter)
-
-
-def year_of_scrobbles(user=None, media: str = 'tracks') -> dict[str, int]:
-
-    return {}
-
-
 def top_tracks(
-    user: "User", filter: str = "today", limit: int = 15
+    user: "User", filter: str = "today", limit: int = 30
 ) -> List["Track"]:
 
     now = timezone.now()
@@ -165,7 +109,9 @@ def top_tracks(
     starting_day_of_current_month = now.date().replace(day=1)
     starting_day_of_current_year = now.date().replace(month=1, day=1)
 
-    time_filter = Q(scrobble__timestamp__gte=start_of_today)
+    time_filter = Q()
+    if filter == "today":
+        time_filter = Q(scrobble__timestamp__gte=start_of_today)
     if filter == "week":
         time_filter = Q(scrobble__timestamp__gte=starting_day_of_current_week)
     if filter == "month":
@@ -175,7 +121,13 @@ def top_tracks(
 
     return (
         Track.objects.filter(time_filter)
-        .annotate(num_scrobbles=Count("scrobble", distinct=True))
+        .annotate(
+            num_scrobbles=Count(
+                "scrobble",
+                filter=Q(scrobble__played_to_completion=True),
+                distinct=True,
+            )
+        )
         .order_by("-num_scrobbles")[:limit]
     )
 
@@ -199,8 +151,14 @@ def top_artists(
 
     return (
         Artist.objects.filter(time_filter)
-        .annotate(num_scrobbles=Count("track__scrobble", distinct=True))
-        .order_by("-num_scrobbles")[:limit]
+        .annotate(
+            num_scrobbles=Count(
+                "track__scrobble",
+                filter=Q(track__scrobble__played_to_completion=True),
+                distinct=True,
+            )
+        )
+        .order_by("-num_scrobbles")
     )
 
 
