@@ -2,19 +2,21 @@ import calendar
 import logging
 from uuid import uuid4
 
+from books.models import Book
 from django.contrib.auth import get_user_model
 from django.db import models
+from django.urls import reverse
 from django.utils import timezone
 from django_extensions.db.models import TimeStampedModel
 from music.models import Artist, Track
-from books.models import Book
 from podcasts.models import Episode
-from profiles.utils import now_user_timezone
 from scrobbles.lastfm import LastFM
 from scrobbles.utils import check_scrobble_for_finish
 from sports.models import SportEvent
 from videos.models import Series, Video
 
+from vrobbler.apps.scrobbles.stats import build_charts
+
 logger = logging.getLogger(__name__)
 User = get_user_model()
 BNULL = {"blank": True, "null": True}
@@ -34,6 +36,24 @@ class BaseFileImportMixin(TimeStampedModel):
     def __str__(self):
         return f"Scrobble import {self.id}"
 
+    @property
+    def human_start(self):
+        start = "Unknown"
+        if self.processing_started:
+            start = self.processing_started.strftime('%B %d, %Y at %H:%M')
+        return start
+
+    @property
+    def import_type(self) -> str:
+        class_name = self.__class__.__name__
+        if class_name == 'AudioscrobblerTSVImport':
+            return "Audioscrobbler"
+        if class_name == 'KoReaderImport':
+            return "KoReader"
+        if self.__class__.__name__ == 'LastFMImport':
+            return "LastFM"
+        return "Generic"
+
     def process(self, force=False):
         logger.warning("Process not implemented")
 
@@ -98,6 +118,14 @@ class KoReaderImport(BaseFileImportMixin):
     class Meta:
         verbose_name = "KOReader Import"
 
+    def __str__(self):
+        return f"KoReader import on {self.human_start}"
+
+    def get_absolute_url(self):
+        return reverse(
+            'scrobbles:koreader-import-detail', kwargs={'slug': self.uuid}
+        )
+
     def get_path(instance, filename):
         extension = filename.split('.')[-1]
         uuid = instance.uuid
@@ -126,6 +154,14 @@ class AudioScrobblerTSVImport(BaseFileImportMixin):
     class Meta:
         verbose_name = "AudioScrobbler TSV Import"
 
+    def __str__(self):
+        return f"Audioscrobbler import on {self.human_start}"
+
+    def get_absolute_url(self):
+        return reverse(
+            'scrobbles:tsv-import-detail', kwargs={'slug': self.uuid}
+        )
+
     def get_path(instance, filename):
         extension = filename.split('.')[-1]
         uuid = instance.uuid
@@ -158,6 +194,14 @@ class LastFmImport(BaseFileImportMixin):
     class Meta:
         verbose_name = "Last.FM Import"
 
+    def __str__(self):
+        return f"LastFM import on {self.human_start}"
+
+    def get_absolute_url(self):
+        return reverse(
+            'scrobbles:lastfm-import-detail', kwargs={'slug': self.uuid}
+        )
+
     def process(self, import_all=False):
         """Import scrobbles found on LastFM"""
         if self.processed_finished:
@@ -203,6 +247,7 @@ class ChartRecord(TimeStampedModel):
 
     user = models.ForeignKey(User, on_delete=models.DO_NOTHING, **BNULL)
     rank = models.IntegerField()
+    count = models.IntegerField(default=0)
     year = models.IntegerField(default=timezone.now().year)
     month = models.IntegerField(**BNULL)
     week = models.IntegerField(**BNULL)
@@ -219,6 +264,8 @@ class ChartRecord(TimeStampedModel):
             media_obj = self.video
         if self.track:
             media_obj = self.track
+        if self.artist:
+            media_obj = self.artist
         return media_obj
 
     @property
@@ -267,6 +314,26 @@ class ChartRecord(TimeStampedModel):
     def __str__(self):
         return f"#{self.rank} in {self.period} - {self.media_obj}"
 
+    @classmethod
+    def build(cls, user, **kwargs):
+        build_charts(user=user, **kwargs)
+
+    @classmethod
+    def for_year(cls, user, year):
+        return cls.objects.filter(year=year, user=user)
+
+    @classmethod
+    def for_month(cls, user, year, month):
+        return cls.objects.filter(year=year, month=month, user=user)
+
+    @classmethod
+    def for_day(cls, user, year, day, month):
+        return cls.objects.filter(year=year, month=month, day=day, user=user)
+
+    @classmethod
+    def for_week(cls, user, year, week):
+        return cls.objects.filter(year=year, week=week, user=user)
+
 
 class Scrobble(TimeStampedModel):
     """A scrobble tracks played media items by a user."""
