@@ -87,17 +87,17 @@ class RecentScrobbleList(ListView):
             data['sport_scrobble_list'] = completed_for_user.filter(
                 sport_event__isnull=False
             ).order_by('-timestamp')[:15]
+            data['active_imports'] = AudioScrobblerTSVImport.objects.filter(
+                processing_started__isnull=False,
+                processed_finished__isnull=True,
+                user=self.request.user,
+            )
 
         data["weekly_data"] = week_of_scrobbles(user=user)
 
         data['counts'] = scrobble_counts(user)
         data['imdb_form'] = ScrobbleForm
         data['export_form'] = ExportScrobbleForm
-        data['active_imports'] = AudioScrobblerTSVImport.objects.filter(
-            processing_started__isnull=False,
-            processed_finished__isnull=True,
-            user=self.request.user,
-        )
         return data
 
     def get_queryset(self):
@@ -468,11 +468,11 @@ class ChartRecordView(TemplateView):
 
     def get_context_data(self, **kwargs):
         context_data = super().get_context_data(**kwargs)
-        date = self.request.GET.get('date')
-        media_type = self.request.GET.get('media')
+        date = self.request.GET.get("date")
+        media_type = self.request.GET.get("media", "Track")
         user = self.request.user
         params = {}
-        context_data['artist_charts'] = {}
+        context_data["artist_charts"] = {}
 
         if not date:
             context_data['artist_charts'] = {
@@ -543,6 +543,7 @@ class ChartRecordView(TemplateView):
             # TODO recalculate
             ...
 
+        context_data['charts'] = charts
         context_data['name'] = name
         context_data['in_progress'] = in_progress
         return context_data
